/* SPDX-License-Identifier: GPL-2.0-only */
#ifndef __DT_BINDINGS_ADI_ADAU1977_H__
#define __DT_BINDINGS_ADI_ADAU1977_H__

#define ADAU1977_MICBIAS_5V0	0x0
#define ADAU1977_MICBIAS_5V5	0x1
#define ADAU1977_MICBIAS_6V0	0x2
#define ADAU1977_MICBIAS_6V5	0x3
#define ADAU1977_MICBIAS_7V0	0x4
#define ADAU1977_MICBIAS_7V5	0x5
#define ADAU1977_MICBIAS_8V0	0x6
#define ADAU1977_MICBIAS_8V5	0x7
#define ADAU1977_MICBIAS_9V0	0x8

#endif /* __DT_BINDINGS_ADI_ADAU1977_H__ */
