/* SPDX-License-Identifier: (GPL-2.0+ OR MIT) */
/*
 * Copyright (c) 2021 Amlogic, Inc.
 * Author: Shunzhou Jiang <shunzhou.jiang@amlogic.com>
 */

#ifndef _DT_BINDINGS_MESON_S4_POWER_H
#define _DT_BINDINGS_MESON_S4_POWER_H

#define PWRC_S4_DOS_HEVC_ID	0
#define PWRC_S4_DOS_VDEC_ID	1
#define PWRC_S4_VPU_HDMI_ID	2
#define PWRC_S4_USB_COMB_ID	3
#define PWRC_S4_GE2D_ID		4
#define PWRC_S4_ETH_ID		5
#define PWRC_S4_DEMOD_ID	6
#define PWRC_S4_AUDIO_ID	7

#endif
