/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (c) 2007-2011 Nicira Networks.
 */

#ifndef _LINUX_OPENVSWITCH_H
#define _LINUX_OPENVSWITCH_H 1

#include <uapi/linux/openvswitch.h>

#define OVS_CLONE_ATTR_EXEC      0   /* Specify an u32 value. When nonzero,
				      * actions in clone will not change flow
				      * keys. False otherwise.
				      */

#endif /* _LINUX_OPENVSWITCH_H */
