/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (C) 2021 Pengutronix, Ahmad Fatoum <kernel@pengutronix.de>
 */

#ifndef __CAAM_TRUSTED_KEY_H
#define __CAAM_TRUSTED_KEY_H

extern struct trusted_key_ops trusted_key_caam_ops;

#endif
