/* SPDX-License-Identifier: GPL-2.0-only */
/*
 * Copyright (c) 2019, The Linux Foundation. All rights reserved.
 */

#ifndef _DT_BINDINGS_CLK_QCOM_GPU_CC_SC7180_H
#define _DT_BINDINGS_CLK_QCOM_GPU_CC_SC7180_H

#define GPU_CC_PLL1			0
#define GPU_CC_AHB_CLK			1
#define GPU_CC_CRC_AHB_CLK		2
#define GPU_CC_CX_GMU_CLK		3
#define GPU_CC_CX_SNOC_DVM_CLK		4
#define GPU_CC_CXO_AON_CLK		5
#define GPU_CC_CXO_CLK			6
#define GPU_CC_GMU_CLK_SRC		7

/* GPU_CC GDSCRs */
#define CX_GDSC				0
#define GX_GDSC				1

#endif
