/* SPDX-License-Identifier: GPL-2.0-only OR BSD-2-Clause */

#ifndef __DT_BINDINGS_MEDIATEK_MT6370_ADC_H__
#define __DT_BINDINGS_MEDIATEK_MT6370_ADC_H__

/* ADC Channel Index */
#define MT6370_CHAN_VBUSDIV5	0
#define MT6370_CHAN_VBUSDIV2	1
#define MT6370_CHAN_VSYS	2
#define MT6370_CHAN_VBAT	3
#define MT6370_CHAN_TS_BAT	4
#define MT6370_CHAN_IBUS	5
#define MT6370_CHAN_IBAT	6
#define MT6370_CHAN_CHG_VDDP	7
#define MT6370_CHAN_TEMP_JC	8
#define MT6370_CHAN_MAX		9

#endif
