/* SPDX-License-Identifier: (GPL-2.0-only OR BSD-2-Clause) */
/*
 * Copyright (c) 2019, The Linux Foundation. All rights reserved.
 * Copyright (c) 2023, Linaro Limited
 */

#ifndef _DT_BINDINGS_RESET_QCOM_GPU_CC_SM8450_H
#define _DT_BINDINGS_RESET_QCOM_GPU_CC_SM8450_H

#define GPUCC_GPU_CC_ACD_BCR			0
#define GPUCC_GPU_CC_CX_BCR			1
#define GPUCC_GPU_CC_FAST_HUB_BCR		2
#define GPUCC_GPU_CC_FF_BCR			3
#define GPUCC_GPU_CC_GFX3D_AON_BCR		4
#define GPUCC_GPU_CC_GMU_BCR			5
#define GPUCC_GPU_CC_GX_BCR			6
#define GPUCC_GPU_CC_XO_BCR			7
#define GPUCC_GPU_CC_GX_ACD_IROOT_BCR		8

#endif
